Name:          muse
Summary:       Midi/Audio Music Sequencer
# Epoch is set to 1 for PlanetCCRMA compatibility.
# See: https://fedoraproject.org/wiki/AudioCreation
Epoch:         1
Version:       1.0.1
Release:       2%{?dist}
# synti/vam is GPLv2+
# original freeverb plugin was public domain
# some of the widgets are GPLv2
# ladspa.h is LGPLv2+
# givertcap (not built) is GPLv2
# The rest, including the core of muse is distributed under GPL+
# Source1 is GPLv2+
License:       GPL+ and GPLv2 and GPLv2+ and LGPLv2+
Group:         Applications/Multimedia
URL:           http://www.muse-sequencer.org/
Source0:       http://downloads.sourceforge.net/project/lmuse/%{name}-1.0/%{name}-1.0/%{name}-%{version}.tar.gz
# The following file and patches are sent upstream on Dec 24 2009:
# http://sourceforge.net/mailarchive/forum.php?forum_name=lmuse-developer
# Compilation of sse bits fail on x86_64. This file fixes the problem
Source1:       sse_functions_64bit.s
# Fix Compilation against glibc-2.12
Patch0:        muse-glibc212.patch
# Add missing condition on an #if to make the sse optimization effective
Patch1:        muse-x86_64-sse.patch
BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: alsa-lib-devel
BuildRequires: desktop-file-utils
BuildRequires: docbook-style-dsssl
BuildRequires: doxygen
BuildRequires: dssi-devel
BuildRequires: fluidsynth-devel
BuildRequires: graphviz
BuildRequires: jack-audio-connection-kit-devel
BuildRequires: lash-devel
BuildRequires: libcap-devel
BuildRequires: liblo-devel
BuildRequires: libsamplerate-devel
BuildRequires: libsndfile-devel
BuildRequires: libtool
BuildRequires: openjade
BuildRequires: pkgconfig
BuildRequires: python-devel
BuildRequires: qt3-devel
BuildRequires: readline-devel

Requires:      hicolor-icon-theme

%description
MusE is a MIDI/Audio sequencer with recording and editing capabilities. It can
perform audio effects like chorus/flanger in real-time via LASH and it supports
Jack and ALSA interfaces. MusE aims to be a complete multitrack virtual studio 
for Linux.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

# Fix encoding issues (upstream is informed):
for f in README.de README.softsynth SECURITY synti/vam/README; do
   iconv -f ISO-8859-1 -t UTF-8 $f > $f.tmp
   touch -r $f $f.tmp
   mv -f $f.tmp $f
done

# Fix compilaton of the sse bits
%ifarch x86_64
cp %{SOURCE1} al/dspSSE.cpp
%endif

# Fix one more 64bit libdir issue
# A proper patch is sent upstream which needs
# a full autohell cycle. For now we do:
sed -i 's|/lib|/%{_lib}|' muse/app.cpp


%build
%configure --disable-suid-build \
           --disable-suid-install \
           --with-docbook-stylesheets=%{_datadir}/sgml/docbook/dsssl-stylesheets \
           --disable-qttest \
           --with-qt-prefix=${QTDIR} \
           --enable-lash \
%ifarch x86_64
           --enable-sse \
%endif
           --enable-python \
           --enable-dssi \
           --enable-static=no 

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Kill *.la files
rm -f %{buildroot}/%{_libdir}/%{name}/*/*.la

# Someone might find the demos useful
mkdir -p %{buildroot}%{_datadir}/%{name}/demos
cp -a demos/*.med %{buildroot}%{_datadir}/%{name}/demos

# German html doc files
mkdir de
mv doc/*.{png,htm} de

# There are bunch of doc files spread into subdirectories. Sort them out:
mv synti/simpledrums/ReleaseNotes.txt   ReleaseNotes.simpledrums
mv synti/simpledrums/COPYING            COPYING.simpledrums
mv synti/simpledrums/README             README.simpledrums
mv synti/fluidsynth/TODO                TODO.fluidsynth
mv synti/fluidsynth/README.txt          README.fluidsynth
mv synti/deicsonze/TODO                 TODO.deicsonze
mv synti/vam/TODO                       TODO.vam
mv synti/vam/ChangeLog                  ChangeLog.vam
mv synti/vam/COPYING                    COPYING.vam
mv synti/vam/README                     README.vam
mv plugins/freeverb/readme.txt          README.freeverb

# install icon in proper freedesktop location
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/64x64/apps
install -pm 0644 packaging/muse_icon.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/

# do not Provide plugins .so
%global _use_internal_dependency_generator 0
cat << \EOF > %{name}.prov
#!%{_buildshell}
grep -v %{_docdir} - | %{__find_provides} $* \
     | sed '/\.so\(()(64bit)\)\?$/d'
EOF

%global __find_provides %{_builddir}/%{name}-%{version}%{?prerelease}/%{name}.prov
chmod +x %{__find_provides}


%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop

%clean
rm -rf %{buildroot}

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog* COPYING* NEWS 
%doc README* ReleaseNotes* SECURITY TODO* de
%{_bindir}/%{name}
%{_bindir}/grepmidi
%{_bindir}/%{name}-find-unused-wavs
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/*

%changelog 
* Wed Apr 07 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0.1-2
- Correct synti path on 64bit systems
- Remove the -fno-var-tracking-assignments workaround
- Rebuild needed on F-13 to pick up the proper soname deps. RHBZ#566419

* Sat Jan 30 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0.1-1
- Update to 1.0.1
- Drop upstreamed patches

* Thu Dec 24 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-1
- Update to 1.0

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.0-0.7.rc3.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 17 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-0.7.rc3
- Bugfix: muse doesn't start properly on x86_64 on F-11+. Backport glibc-2.10 patch from trunk
- Remove BR: e2fsprogs-devel

* Sat Jun 20 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-0.6.rc3
- Update to 1.0rc3

* Wed May 13 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-0.5.rc2
- Update to 1.0rc2

* Mon Feb 23 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-0.4.rc1
- Updated icon cache scriptlets according to the new guidlines

* Mon Feb 23 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-0.3.rc1
- Handle the Provides list within the SPEC file
- Add gcc-4.4 patch
- Fix size_t warnings
- Explain the various licenses

* Sun Feb 08 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-0.2.rc1
- Use AutoProv=no instead of AutoReqProv=no

* Sat Feb 07 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:1.0-0.1.rc1
- New upstream release with many bugfixes.
- Remove the patches that are committed upstream.

* Fri Jan 30 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 1:0.9-3
- PlanetCCRMA's SPEC revised for Fedora submission

* Tue Jul 15 2008 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1:0.9-2
- updated qt3-devel build dependency for fc9
- added patch for gcc4.3 build on fc9

* Fri Feb  1 2008 Arnaud Gomes-do-Vale <Arnaud.Gomes@ircam.fr>
- built on CentOS

* Sat Nov 17 2007 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.9-2
- added patch from Debian to avoid using internal lash api calls that
  are not there in last 0.5.3

* Tue Oct  9 2007 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.9-1
- updated to 0.9
- adjusted desktop categories

* Thu Dec 21 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.8.1a-2
- spec file tweaks, build on fc6
- make sure LADSPA plugins are searched in the right lib directory
  for all architectures

* Thu May  5 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- added icon and Planet CCRMA categories

* Tue Mar 28 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.8.1a-1
- updated to 0.8.1a

* Mon Jan 23 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.7.2-0.1.pre5
- updated to 0.7.2-pre5

* Sun Nov 20 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- the internal libraries appear in the provides list and conflict with
  old names, for example the obsolete "fluid" package name as now
  included in pd-fluid, so disable automatic provide generation. 

* Fri Nov 18 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.7.2-0.1.pre3
- update to 0.7.2pre3
- build with lash (name change from ladcca)
- added readline-devel (needed by lash)
- delete --enable-rtcap option to configure

* Sun Jun 25 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- do not create givertcap package anymore, fc4 mach is confused by
  the version and it is not needed anymore

* Mon Jan 24 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.7.1-1
- updated to 0.7.1
- needs libsamplerate
- added --enable-ladcca configure flag (has to be explicitly enabled)

* Tue Dec 31 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- spec file cleanup

* Sun Sep 26 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- use qt33 package for fc1 and below

* Wed Jul 21 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.7.0-1
- updated to 0.7.0

* Thu May 20 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- added dsssl build requirement

* Thu May  6 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.7.0-0.pre2.1
- updated to 0.7.0 pre2
- needs qt > 3.2
- --disable-suid-install does not work, change default to "no"

* Wed Jan  7 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.3-1
- updated to 0.6.3

* Wed Nov 19 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.2-1
- added alsa patch for old api

* Fri Nov 14 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.2-1
- spec file tweaks
- fix dssslver for 9 and fc1

* Thu Nov  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.2-1
- updated to 0.6.2
- softsynth and jack patches not needed any more

* Sun Sep 14 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.1-2
- applied Takashi's patch for softsynth hangs (patch2)
- fixed build with jack 0.80.0, updated version requirement
- added release tags
- added separate release number for givertcap

* Sat Jul 26 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.1-1
- updated to 0.6.1

* Tue May 20 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0-1
- updated to 0.6.0 final
- added atomic.h borrowed from kernel 2.4.20 (otherwise it does not
  find atomic_inc)
- added instruments directory and files to files list
- added explicit dependency to qt version 

* Fri Apr  4 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0pre8-1
- updated to 0.6.0pre8

* Wed Apr  2 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0pre7-2
- rebuild for jack 0.66.3, added explicit requires for it

* Fri Mar 21 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0pre7-1
- updated to 0.6.0pre7
- changed default qt in 7.3 to 3.0.5, dsss version to 1.76 in 7.3/8.0
- added node.h patch for 7.2/7.3

* Thu Dec  5 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0pre5-1
- updated to 0.6.0pre5

* Thu Nov 14 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0pre3-1
- added patch to fix jack port names
- signals patch no longer needed

* Mon Oct 21 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0pre2-2
- added patch so that signals are not intercepted, that hungs muse
  on startup under rh 8.0's thread libraries
- disabled qttest, otherwise you have to build while logged in as root
  in the console
- added proper menu entries

* Mon Oct 21 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.6.0pre2-1
- updated to 0.6.0pre2, enabled jack support

* Mon Jun 24 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.5.3-1
- updated to 0.5.3b
- enabled rtcaps, added givertcap package
- updated doc file list
- added make -j for smp builds

* Fri Apr 19 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.5.2-1
- updated to 0.5.2, needs qt 3.0.3 (from rawhide)

* Wed Nov 28 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.4.14-1
- updated to 0.4.14, adjusted file list

* Tue Nov 27 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- updated to 0.4.16 (added qt3 rpms)
- patch1: remove su's
- patch2: configuration, 3 and 4 suggested patches on the muse list
- cannot make 0.4.16 compile...

* Thu Aug 23 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.4.8-1
- adapted suse's srpm to redhat

* Fri May 11 2001 - <<tiwai@suse.de>>
- fixed build.
* Wed May 09 2001 - <tiwai@suse.de>
- updated to muse-0.3.19.
* Wed Apr 11 2001 - <tiwai@suse.de>
- updated to muse-0.3.16.
* Wed Apr 04 2001 - <tiwai@suse.de>
- updated to muse-0.3.15.
* Tue Mar 20 2001 - <tiwai@suse.de>
- fixed neededforbuild.
* Fri Mar 16 2001 - <tiwai@suse.de>
- updated to muse-0.3.12.
* Mon Mar 12 2001 - <tiwai@suse.de>
- updated to muse-0.3.11.
* Wed Mar 07 2001 - ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Wed Mar 07 2001 - <tiwai@suse.de>
- Updated to muse-0.3.10.
* Mon Feb 26 2001 - <tiwai@suse.de>
- Updated to muse-0.3.9.
* Mon Feb 12 2001 - <tiwai@suse.de>
- Updated to muse-0.3.7.
* Fri Feb 09 2001 - <tiwai@suse.de>
- Updated to muse-0.3.6.
* Tue Jan 30 2001 - <tiwai@suse.de>
- Updated to muse-0.3.5.
* Fri Dec 01 2000 - ro@suse.de
- added liblcms to neededforbuild
* Thu Nov 23 2000 - <tiwai@suse.de>
- Updated to muse-0.2.12.
* Fri Nov 17 2000 - <tiwai@suse.de>
- Updated to muse-0.2.10.
* Fri Nov 17 2000 - ro@suse.de
- fixed neededforbuild: += libmng-devel
* Wed Nov 08 2000 - <tiwai@suse.de>
- Updated to muse-0.2.7.
- Fixed to compile.
* Mon Nov 06 2000 - ro@suse.de
- fixed to compile (include spinlock before mc146818rtc)
* Fri Nov 03 2000 - <tiwai@suse.de>
- Updated to muse-0.2.6.
- Fixed spec file for long package-name support.
- Excluded plug-ins from provide list.
* Mon Oct 09 2000 - <tiwai@suse.de>
- Added libmng to neededforbuild
* Fri Oct 06 2000 - <tiwai@suse.de>
- Updated to muse-0.2.4
* Wed Sep 27 2000 - <tiwai@suse.de>
- Fixed compile for alpha and ppc.
* Tue Sep 26 2000 - <tiwai@suse.de>
- Update to 0.2.3
* Mon Aug 28 2000 - <tiwai@suse.de>
- Update to 0.2.1.
- Disable translations (due to change of qt-2.2).
* Wed Aug 02 2000 - <tiwai@suse.de> 
- Initial version: 0.1.10.  No manual document is included.
